==> affy_1.24.2.zip: affy/doc/affy.R <==
###################################################
### chunk number 1: 
###################################################
library(affy)


###################################################
### chunk number 2: 
###################################################
bgcorrect.methods()


###################################################
### chunk number 3: 
###################################################
library(affydata)
data(Dilution) ##data included in the package for examples
normalize.methods(Dilution)


###################################################
### chunk number 4: 
###################################################
pmcorrect.methods()


###################################################
### chunk number 5: 
###################################################
express.summary.stat.methods()


###################################################
### chunk number 6: 
###################################################
eset <- mas5(Dilution)


###################################################
### chunk number 7: 
###################################################
Calls <- mas5calls(Dilution)


###################################################
### chunk number 8: 
###################################################
eset <- rma(Dilution)


###################################################
### chunk number 9: 
###################################################
Dilution


###################################################
### chunk number 10: 
###################################################
phenoData(Dilution)
pData(Dilution)


###################################################
### chunk number 11: 
###################################################
data(Dilution)
MAplot(Dilution,pairs=TRUE,plot.method="smoothScatter")


###################################################
### chunk number 12: 
###################################################
Index <- c(1,2,3,100,1000,2000) ##6 arbitrary probe positions
pm(Dilution)[Index,]
mm(Dilution)[Index,]
probeNames(Dilution)[Index]


###################################################
### chunk number 13: 
###################################################
sampleNames(Dilution)


###################################################
### chunk number 14: 
###################################################
mean(mm(Dilution)>pm(Dilution))


###################################################
### chunk number 15: 
###################################################
gn <- geneNames(Dilution)
pm(Dilution, gn[100])


###################################################
### chunk number 16: 
###################################################
hist(Dilution[,1:2]) ##PM histogram of arrays 1 and 2


###################################################
### chunk number 17:  eval=FALSE
###################################################
## par(mfrow=c(2,2))
## image(Dilution)


###################################################
### chunk number 18: 
###################################################
par(mfrow=c(1,1))
boxplot(Dilution, col=c(2,3,4))


###################################################
### chunk number 19: 
###################################################
deg <- AffyRNAdeg(Dilution)
names(deg)


###################################################
### chunk number 20: 
###################################################
summaryAffyRNAdeg(deg)


###################################################
### chunk number 21: 
###################################################
plotAffyRNAdeg(deg)


###################################################
### chunk number 22: 
###################################################
Dilution.normalized <- normalize(Dilution)


###################################################
### chunk number 23: 
###################################################
gn <- featureNames(Dilution)
ps <- probeset(Dilution, gn[1:2])
#this is what i should be using: ps
show(ps[[1]])


###################################################
### chunk number 24: 
###################################################
mylocation <- list("1000_at"=cbind(pm=c(1,2,3),mm=c(4,5,6)),
                   "1001_at"=cbind(pm=c(4,5,6),mm=c(1,2,3)))


###################################################
### chunk number 25: 
###################################################
ps <- probeset(Dilution, genenames=c("1000_at","1001_at"),
                 locations=mylocation)


###################################################
### chunk number 26: 
###################################################
pm(ps[[1]])
mm(ps[[1]])
pm(ps[[2]])
mm(ps[[2]])


###################################################
### chunk number 27: 
###################################################
data(SpikeIn) ##SpikeIn is a ProbeSets
pms <- pm(SpikeIn)
mms <- mm(SpikeIn)

##pms follow concentration
par(mfrow=c(1,2))
concentrations <- matrix(as.numeric(sampleNames(SpikeIn)),20,12,byrow=TRUE)
matplot(concentrations,pms,log="xy",main="PM",ylim=c(30,20000))
lines(concentrations[1,],apply(pms,2,mean),lwd=3)
##so do mms
matplot(concentrations,mms,log="xy",main="MM",ylim=c(30,20000))
lines(concentrations[1,],apply(mms,2,mean),lwd=3)


###################################################
### chunk number 28: 
###################################################
cat("HG_U95Av2 is",cleancdfname("HG_U95Av2"),"\n")
cat("HG-133A is",cleancdfname("HG-133A"),"\n")


###################################################
### chunk number 29: 
###################################################
cat("HG_U95Av2 is",cleancdfname("HG_U95Av2",addcdf=FALSE),"\n")


###################################################
### chunk number 30: 
###################################################
data(cdfenv.example)
ls(cdfenv.example)[1:5]
get(ls(cdfenv.example)[1],cdfenv.example)


###################################################
### chunk number 31: 
###################################################
print(Dilution@cdfName)
myenv <- getCdfInfo(Dilution)
ls(myenv)[1:5]


###################################################
### chunk number 32: 
###################################################
Index <- pmindex(Dilution)
names(Index)[1:2]
Index[1:2]


###################################################
### chunk number 33: 
###################################################
pmindex(Dilution, genenames=c("1000_at","1001_at"))


###################################################
### chunk number 34: 
###################################################
mmindex(Dilution, genenames=c("1000_at","1001_at"))


###################################################
### chunk number 35: 
###################################################
indexProbes(Dilution, which="pm")[1]
indexProbes(Dilution, which="mm")[1]
indexProbes(Dilution, which="both")[1]


###################################################
### chunk number 36: 
###################################################
opt <- getOption("BioC")
affy.opt <- opt$affy
print(names(affy.opt))


###################################################
### chunk number 37: 
###################################################
opt <- getOption("BioC")
affy.opt <- opt$affy
affy.opt$normalize.method <- "constant"
opt$affy <- affy.opt
options(BioC=opt)


###################################################
### chunk number 38: 
###################################################
opt <- getOption("BioC")
affy.opt <- opt$affy
affy.opt$compress.cel <- TRUE
opt$affy <- affy.opt
options(BioC=opt)

==> affy_1.28.1.zip: affy/doc/affy.R <==
###################################################
### chunk number 1: 
###################################################
#line 119 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
library(affy)


###################################################
### chunk number 2: 
###################################################
#line 324 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
bgcorrect.methods()


###################################################
### chunk number 3: 
###################################################
#line 331 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
library(affydata)
data(Dilution) ##data included in the package for examples
normalize.methods(Dilution)


###################################################
### chunk number 4: 
###################################################
#line 339 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
pmcorrect.methods()


###################################################
### chunk number 5: 
###################################################
#line 345 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
express.summary.stat.methods()


###################################################
### chunk number 6: 
###################################################
#line 381 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
eset <- mas5(Dilution)


###################################################
### chunk number 7: 
###################################################
#line 391 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
Calls <- mas5calls(Dilution)


###################################################
### chunk number 8: 
###################################################
#line 416 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
eset <- rma(Dilution)


###################################################
### chunk number 9: 
###################################################
#line 440 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
Dilution


###################################################
### chunk number 10: 
###################################################
#line 455 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
phenoData(Dilution)
pData(Dilution)


###################################################
### chunk number 11: 
###################################################
#line 477 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
data(Dilution)
MAplot(Dilution,pairs=TRUE,plot.method="smoothScatter")


###################################################
### chunk number 12: 
###################################################
#line 494 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
Index <- c(1,2,3,100,1000,2000) ##6 arbitrary probe positions
pm(Dilution)[Index,]
mm(Dilution)[Index,]
probeNames(Dilution)[Index]


###################################################
### chunk number 13: 
###################################################
#line 507 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
sampleNames(Dilution)


###################################################
### chunk number 14: 
###################################################
#line 513 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
mean(mm(Dilution)>pm(Dilution))


###################################################
### chunk number 15: 
###################################################
#line 519 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
gn <- geneNames(Dilution)
pm(Dilution, gn[100])


###################################################
### chunk number 16: 
###################################################
#line 535 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
hist(Dilution[,1:2]) ##PM histogram of arrays 1 and 2


###################################################
### chunk number 17:  eval=FALSE
###################################################
## #line 552 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
## par(mfrow=c(2,2))
## image(Dilution)


###################################################
### chunk number 18: 
###################################################
#line 570 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
par(mfrow=c(1,1))
boxplot(Dilution, col=c(2,3,4))


###################################################
### chunk number 19: 
###################################################
#line 595 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
deg <- AffyRNAdeg(Dilution)
names(deg)


###################################################
### chunk number 20: 
###################################################
#line 601 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
summaryAffyRNAdeg(deg)


###################################################
### chunk number 21: 
###################################################
#line 609 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
plotAffyRNAdeg(deg)


###################################################
### chunk number 22: 
###################################################
#line 624 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
Dilution.normalized <- normalize(Dilution)


###################################################
### chunk number 23: 
###################################################
#line 671 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
gn <- featureNames(Dilution)
ps <- probeset(Dilution, gn[1:2])
#this is what i should be using: ps
show(ps[[1]])


###################################################
### chunk number 24: 
###################################################
#line 691 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
mylocation <- list("1000_at"=cbind(pm=c(1,2,3),mm=c(4,5,6)),
                   "1001_at"=cbind(pm=c(4,5,6),mm=c(1,2,3)))


###################################################
### chunk number 25: 
###################################################
#line 700 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
ps <- probeset(Dilution, genenames=c("1000_at","1001_at"),
                 locations=mylocation)


###################################################
### chunk number 26: 
###################################################
#line 706 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
pm(ps[[1]])
mm(ps[[1]])
pm(ps[[2]])
mm(ps[[2]])


###################################################
### chunk number 27: 
###################################################
#line 729 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
data(SpikeIn) ##SpikeIn is a ProbeSets
pms <- pm(SpikeIn)
mms <- mm(SpikeIn)

##pms follow concentration
par(mfrow=c(1,2))
concentrations <- matrix(as.numeric(sampleNames(SpikeIn)),20,12,byrow=TRUE)
matplot(concentrations,pms,log="xy",main="PM",ylim=c(30,20000))
lines(concentrations[1,],apply(pms,2,mean),lwd=3)
##so do mms
matplot(concentrations,mms,log="xy",main="MM",ylim=c(30,20000))
lines(concentrations[1,],apply(mms,2,mean),lwd=3)


###################################################
### chunk number 28: 
###################################################
#line 775 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
cat("HG_U95Av2 is",cleancdfname("HG_U95Av2"),"\n")
cat("HG-133A is",cleancdfname("HG-133A"),"\n")


###################################################
### chunk number 29: 
###################################################
#line 781 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
cat("HG_U95Av2 is",cleancdfname("HG_U95Av2",addcdf=FALSE),"\n")


###################################################
### chunk number 30: 
###################################################
#line 789 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
data(cdfenv.example)
ls(cdfenv.example)[1:5]
get(ls(cdfenv.example)[1],cdfenv.example)


###################################################
### chunk number 31: 
###################################################
#line 803 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
print(Dilution@cdfName)
myenv <- getCdfInfo(Dilution)
ls(myenv)[1:5]


###################################################
### chunk number 32: 
###################################################
#line 814 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
Index <- pmindex(Dilution)
names(Index)[1:2]
Index[1:2]


###################################################
### chunk number 33: 
###################################################
#line 821 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
pmindex(Dilution, genenames=c("1000_at","1001_at"))


###################################################
### chunk number 34: 
###################################################
#line 826 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
mmindex(Dilution, genenames=c("1000_at","1001_at"))


###################################################
### chunk number 35: 
###################################################
#line 830 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
indexProbes(Dilution, which="pm")[1]
indexProbes(Dilution, which="mm")[1]
indexProbes(Dilution, which="both")[1]


###################################################
### chunk number 36: 
###################################################
#line 845 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
opt <- getOption("BioC")
affy.opt <- opt$affy
print(names(affy.opt))


###################################################
### chunk number 37: 
###################################################
#line 852 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
opt <- getOption("BioC")
affy.opt <- opt$affy
affy.opt$normalize.method <- "constant"
opt$affy <- affy.opt
options(BioC=opt)


###################################################
### chunk number 38: 
###################################################
#line 863 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp69fBhZ/R.INSTALL68a4112d/affy/inst/doc/affy.Rnw"
opt <- getOption("BioC")
affy.opt <- opt$affy
affy.opt$compress.cel <- TRUE
opt$affy <- affy.opt
options(BioC=opt)
